/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: main-unix.c,v 1.24 2009/06/26 16:58:16 bowkenken Exp $
***************************************************************/

/***************************************************************
* UNIX ѤΥᥤ
***************************************************************/

#define	MAIN_UNIX_C
#include	"inc.h"

/***************************************************************
* ᥤ󡦥롼
* int argc : ο
* char **argv : Υꥹ
* return : λ
***************************************************************/

int	main( int argc, char **argv )
{
	init_arg();
	chk_arg( argc, argv );

	init_game();

	game_main();

	return EXIT_FAILURE;
}

/***************************************************************
* ƥåѿꥻå
***************************************************************/

void	reset_static_main_unix( void )
{
}

/***************************************************************
* λ
* long code : λ
***************************************************************/

void	gexit( long code )
{
	exit( code );
}

/***************************************************************
* ꡼å
***************************************************************/

void	check_memory_main_unix_c( void )
{
}
